@@ -16,7 +16,7 @@ has jail => ( is => 'rw' );
 
 has error => ( is => 'rw' );
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.9';
 
 use Lemonldap::NG::Handler::Main '$datas', '$tsv';
 use Lemonldap::NG::Handler::API ':functions';
@@ -79,6 +79,9 @@ sub build_jail {
     $self->jail->share_from( __PACKAGE__, [ @t, '&encrypt' ] );
     $self->jail->share_from( 'MIME::Base64', ['&encode_base64'] );
 
+    # Initialize cryptographic functions to be able to use them in jail.
+    eval { encrypt('a') };
+
     return $self->jail;
 }
 
